==> react-ui-library-1.0.0.tgz: package/src/stories/sheet-story.js <==
import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Sheet,
  Pane,
  Button,
  Content,
  theme
} from '../components'
const { minorScale, majorScale } = theme

class SheetTrigger extends React.Component {
  constructor() {
    super()
    this.toggle = this.toggle.bind(this)
    this.state = {
      isOpen: false
    }
  }

  toggle() {
    this.setState({ isOpen: !this.state.isOpen })
  }

  render() {
    return (
      <Pane>
        <Button primary onClick={this.toggle}>Open Sheet</Button>
        <Sheet isOpen={this.state.isOpen} onClose={this.toggle}>
          <Pane padding>Hello World</Pane>
        </Sheet>
      </Pane>
    )
  }
}

export default function sheetStory (module) {
  storiesOf('Sheet', module)
    .add('usage', () => (
      <App white>
        <Pane padding={majorScale(10)}>
          <Content markdown>
{`
# Sheet

The Sheet component. Implement the \`<Pane />\` component.\

* Don't put spacing on the Sheet itself, the close button will me misaligned

\`\`\`
class SheetTrigger extends React.Component {
  constructor() {
    super()
    this.toggle = this.toggle.bind(this)
    this.state = {
      isOpen: false
    }
  }

  toggle() {
    this.setState({ isOpen: !this.state.isOpen })
  }

  render() {
    return (
      <Pane>
        <Button primary onClick={this.toggle}>Open Sheet</Button>
        <Sheet isOpen={this.state.isOpen} onClose={this.toggle}>
          <Pane padding>Hello World</Pane>
        </Sheet>
      </Pane>
    )
  }
}

<SheetTrigger />
\`\`\`

`}
          </Content>
          <SheetTrigger />
          <Content markdown>
{`
prop | type | default | description
-----|------| --------|-------------
\`isOpen\` | boolean | undefined | is the sheet open
\`onClose\` | function | undefined | onClose handler to manage state
\`width\`| string | \`680px\` | width of the Sheet
`}
          </Content>
        </Pane>
      </App>
    )).add('standalone', () => (
      <SheetTrigger />
    ))
}

==> react-ui-library-2.2.0.tgz: package/src/stories/sheet-story.js <==
import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  Sheet,
  Pane,
  Button,
  Content,
  theme
} from '../components'
const { majorScale } = theme

class SheetTrigger extends React.Component {
  constructor () {
    super()
    this.toggle = this.toggle.bind(this)
    this.state = {
      isOpen: false
    }
  }

  toggle () {
    this.setState({ isOpen: !this.state.isOpen })
  }

  render () {
    return (
      <Pane>
        <Button primary onClick={this.toggle}>Open Sheet</Button>
        <Sheet isOpen={this.state.isOpen} onClose={this.toggle}>
          <Pane padding>Hello World</Pane>
        </Sheet>
      </Pane>
    )
  }
}

export default function sheetStory (module) {
  storiesOf('Sheet', module)
    .add('usage', () => (
      <App white>
        <Pane padding={majorScale(10)}>
          <Content markdown>
            {`
# Sheet

The Sheet component. Implement the \`<Pane />\` component.\

* Don't put spacing on the Sheet itself, the close button will me misaligned

\`\`\`
class SheetTrigger extends React.Component {
  constructor() {
    super()
    this.toggle = this.toggle.bind(this)
    this.state = {
      isOpen: false
    }
  }

  toggle() {
    this.setState({ isOpen: !this.state.isOpen })
  }

  render() {
    return (
      <Pane>
        <Button primary onClick={this.toggle}>Open Sheet</Button>
        <Sheet isOpen={this.state.isOpen} onClose={this.toggle}>
          <Pane padding>Hello World</Pane>
        </Sheet>
      </Pane>
    )
  }
}

<SheetTrigger />
\`\`\`

`}
          </Content>
          <SheetTrigger />
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`isOpen\` | boolean | undefined | is the sheet open
\`onClose\` | function | undefined | onClose handler to manage state
\`width\`| string | \`680px\` | width of the Sheet
`}
          </Content>
        </Pane>
      </App>
    )).add('standalone', () => (
      <SheetTrigger />
    ))
}
